@@ -97,6 +97,7 @@ class Payroll(Workflow, ModelSQL, ModelView):
             })
         cls._transitions |= set((
                 ('draft', 'cancel'),
+                ('cancel', 'draft'),
                 ('draft', 'processed'),
                 ('processed', 'done'),
                 ('processed', 'draft'),
@@ -235,7 +236,8 @@ class Payroll(Workflow, ModelSQL, ModelView):
         pool = Pool()
         Move = pool.get('account.move')
         Period = pool.get('account.period')
-
+        if self.move:
+            return
         period_id = Period.find(self.company.id, date=self.date_effective)
 
         move_lines = self.get_moves_lines()
